import MessageList from './message-list';
import MessageListItem from './message-list-item';
import MessageDetailDefinition from './message-detail-definition';
import MessageAttachments from './message-attachments';
import MessageHtml from './message-html';

export default Object.assign({},
  MessageList,
  MessageListItem,
  MessageDetailDefinition,
  MessageAttachments,
  MessageHtml,
);
